RegistryEntry

Struct RegistryEntry 

pub struct RegistryEntry {
Show 13 fields pub event: HookEvent, pub matcher: Option<String>, pub type: String, pub command: String, pub timeout: Option<u32>, pub async: Option<bool>, pub scope: String, pub enabled: bool, pub added_at: String, pub installed_by: String, pub description: Option<String>, pub reason: Option<String>, pub optional: Option<bool>,
}
Registry entry (internal representation with metadata)

Fields

event: HookEvent

Hook event

matcher: Option<String>

Optional matcher regex (None for hooks without matcher)

type: String

Handler type

command: String

Command string

timeout: Option<u32>

Optional timeout in seconds

async: Option<bool>

Optional async flag

scope: String

Scope (e.g., “user” in v0.1)

enabled: bool

Whether hook is enabled

added_at: String

Timestamp when hook was added (yyyyMMdd-hhmmss)

installed_by: String

Free-form string identifying installer (D24)

description: Option<String>

Optional description of what the hook does

reason: Option<String>

Optional reason why the hook was added

optional: Option<bool>

Optional flag for whether hook is optional

Implementations

Source

impl RegistryEntry

pub fn matches(&self, event: HookEvent, command: &str) -> bool

Check if this entry matches the given event and command (composite key)

This implements the composite key matching logic from D22.